"""Adds helpfule tools for pyqt apps"""

from .inherits_ui_file import inherits_from_ui_file_with_name
from .change_log_dialog import ChangeLogDialog

__all__ = ["inherits_from_ui_file_with_name","ChangeLogDialog"]

__version__ = "0.1.13"

__module_name__ = "pyqtapplicationhelper"
